@@ -128,3 +128,29 @@ class Account(Entity):
         """str: Account name.
         """
         return self._data.get("name")
+
+    def get_statistics_csv(self, utc_start=None, utc_end=None, **params):
+        """Gets all the statistics for an account in a CSV format.
+
+        Args:
+            utc_start (float): Returns statistics starting from the specified timestamp.
+                If null, returns the API default range (1 day).
+            utc_end (float): Returns statistics until the specified timestamp (inclusive).
+                If null, returns the statistics until current hour.
+            **params: Extra parameters that could be included in the request.
+
+        Returns:
+            String object with the CSV content.
+        """
+        if utc_start is not None:
+            params['utc_start'] = utc_start
+        if utc_end is not None:
+            params['utc_end'] = utc_end
+
+        data = api_call(
+            "GET",
+            "/accounts/{}/statistics/csv".format(self._id),
+            raw=True,
+            params=params,
+        )
+        return data
